@@ -1,5 +1,5 @@
 package Mojolicious::Command::export;
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 # ABSTRACT: Export a Mojolicious website to static files
 
 #pod =head1 SYNOPSIS
@@ -28,8 +28,8 @@ our $VERSION = '0.006';
 #pod     # myapp.conf
 #pod     {
 #pod         export => {
-#pod             # Configure the default paths to export
-#pod             paths => [ '/', '/hidden' ],
+#pod             # Configure the default pages to export
+#pod             pages => [ '/', '/hidden' ],
 #pod             # The directory to export to
 #pod             to => '/var/www/html',
 #pod             # Rewrite URLs to include base directory
@@ -85,7 +85,7 @@ Mojolicious::Command::export - Export a Mojolicious website to static files
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -113,8 +113,8 @@ configuration using one of Mojolicious's configuration plugins.
     # myapp.conf
     {
         export => {
-            # Configure the default paths to export
-            paths => [ '/', '/hidden' ],
+            # Configure the default pages to export
+            pages => [ '/', '/hidden' ],
             # The directory to export to
             to => '/var/www/html',
             # Rewrite URLs to include base directory
